@@ -67,7 +67,7 @@ class Client:
         return f"<Client {self.window_handle=} {self.process_id=}>"
 
     @property
-    def title(self):
+    def title(self) -> str:
         """
         Get or set this window's title
         """
@@ -77,6 +77,22 @@ class Client:
     def title(self, window_title: str):
         set_window_title(self.window_handle, window_title)
 
+    @property
+    def is_foreground(self) -> bool:
+        """
+        If this client is the foreground window
+
+        Set this to True to bring it to the foreground
+        """
+        return utils.get_foreground_window() == self.window_handle
+
+    @is_foreground.setter
+    def is_foreground(self, value: bool):
+        if value is False:
+            return
+
+        utils.set_foreground_window(self.window_handle)
+
     @property
     def window_rectangle(self):
         """
@@ -362,15 +378,21 @@ class Client:
         await self.body.write_yaw(yaw)
         await utils.timed_send_key(self.window_handle, Keycode.W, move_seconds)
 
-    async def teleport(self, xyz: XYZ, yaw: int = None):
+    async def teleport(self, xyz: XYZ, yaw: float = None, *, move_after: bool = True):
         """
         Teleport the client
 
         Args:
             xyz: xyz to teleport to
             yaw: yaw to set or None to not change
+
+        Keyword Args:
+            move_after: If the client should rotate some to update the player model position
         """
         await self.body.write_position(xyz)
 
+        if move_after:
+            await self.send_key(Keycode.D, 0.1)
+
         if yaw is not None:
             await self.body.write_yaw(yaw)
